src.core package
================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   src.core.holobits
   src.core.memoria
   src.core.nativos
   src.core.semantic_validators
   src.core.transpiler

Submodules
----------

src.core.ast\_nodes module
--------------------------

.. automodule:: src.core.ast_nodes
   :members:
   :undoc-members:
   :show-inheritance:

src.core.interpreter module
---------------------------

.. automodule:: src.core.interpreter
   :members:
   :undoc-members:
   :show-inheritance:

src.core.lexer module
---------------------

.. automodule:: src.core.lexer
   :members:
   :undoc-members:
   :show-inheritance:

src.core.main module
--------------------

.. automodule:: src.core.main
   :members:
   :undoc-members:
   :show-inheritance:

src.core.parser module
----------------------

.. automodule:: src.core.parser
   :members:
   :undoc-members:
   :show-inheritance:

src.core.semantic\_validator module
-----------------------------------

.. automodule:: src.core.semantic_validator
   :members:
   :undoc-members:
   :show-inheritance:

src.core.visitor module
-----------------------

.. automodule:: src.core.visitor
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: src.core
   :members:
   :undoc-members:
   :show-inheritance:
